..
   This is an autogenerated file from processors.rst

avatars.processors.GroupModalitiesProcessor
===========================================

.. autoclass:: avatars.processors.GroupModalitiesProcessor
   :members: